module Salt
  class Scanner
    module Main
      NUMBER = %{
        (
            [0-9]+
          | 0[xX][0-9a-f]+
          | 0b[01]+
        )
      }

      DOUBLE = %{([0-9]+\.[0-9]+)}

      def scan
        until eos?
          scan_keyword || scan_grouping || scan_logimath ||
            scan_control || scan_string || scan_number ||
            scan_identifier || scan_comment || scan_whitespace ||
            error!
        end
      end

      def scan_keyword
        case
        when on(:function) then emit(:function)
        when on(:func)     then emit(:func)
        when on(:class)    then emit(:class)
        when on(:struct)   then emit(:struct)
        when on(:union)    then emit(:union)
        when on(:continue) then emit(:continue)
        when on(:break)    then emit(:break)
        when on(:if)       then emit(:if)
        when on(:else)     then emit(:else)
        when on(:for)      then emit(:for)
        when on(:while)    then emit(:while)
        when on(:do)       then emit(:do)
        when on(:goto)     then emit(:goto)
        when on(:return)   then emit(:return)
        when on(:typedef)  then emit(:typedef)
        when on(:label)    then emit(:label)
        end
      end

      def scan_grouping
        case
        when on('{') then emit(:lbrace)
        when on('}') then emit(:rbrace)
        when on('(') then emit(:lparen)
        when on(')') then emit(:rparen)
        when on('[') then emit(:lbrack)
        when on(']') then emit(:rbrack)
        end
      end

      def scan_logimath
        case
        when on('++') then emit(:dplus)
        when on('--') then emit(:dminus)
        when on('<<') then emit(:lshift)
        when on('>>') then emit(:rshift)
        when on('==') then emit(:comp)
        when on('!=') then emit(:ncmp)
        when on('&&') then emit(:land)
        when on('||') then emit(:lor)
        when on('=')  then emit(:equals)
        when on('+')  then emit(:plus)
        when on('-')  then emit(:minus)
        when on('/')  then emit(:divide)
        when on('%')  then emit(:mod)
        when on('&')  then emit(:amber)
        when on('^')  then emit(:caret)
        when on('*')  then emit(:star)
        when on('<')  then emit(:lbrk)
        when on('>')  then emit(:rbrk)
        when on('!')  then emit(:lnot)
        when on('~')  then emit(:bnot)
        when on('|')  then emit(:bor)
        end
      end

      def scan_control
        case
        when on('::') then emit(:dcolon)
        when on(':')  then emit(:colon)
        when on(';')  then emit(:semicolon)
        when on('#')  then emit(:hash)
        when on(',')  then emit(:comma)
        end
      end

      def scan_string
        case
        when on(/\" ([^\"] | \\")* \"/)
          emit(:string, group[1])
        when on(/'(.)'/)
          emit(:character, group[1])
        end
      end

      def scan_number
        case
        when on(/#{NUMBER}(ull|llu)/x)
          emit(:ullnumber, group[1])
        when on(/#{NUMBER}(ul|lu)/x)
          emit(:ulnumber, group[1])
        when on(/#{NUMBER}(su|us)/x)
          emit(:usnumber, group[1])
        when on(/#{NUMBER}ll/x)
          emit(:llnumber, group[1])
        when on(/#{NUMBER}l/x)
          emit(:lnumber, group[1])
        when on(/#{NUMBER}s/x)
          emit(:snumber, group[1])
        when on(/#{NUMBER}u/x)
          emit(:unumber, group[1])
        when on(/#{NUMBER}/x)
          emit(:number, group[1])
        when on(/#{DOUBLE}f/)
          emit(:float, group[1])
        when on(DOUBLE)
          emit(:double, group[1])
        end
      end

      def scan_identifier
        emit(:identifier, group[1]) if on(/([A-Za-z][A-Za-z0-9_]*)/)
      end

      def scan_comment
        on(%r{//(.*?)\n})
      end
    end
  end
end
